@@ -220,7 +220,7 @@ class Config(object):
             # self.ee_window_title = r'\[.*\] — Eeschema$'  # "PROJECT [HIERARCHY_PATH] - Eeschema"
             # KiCad 6.0.0 rc1
             self.ee_window_title = r'\[.*\] — Schematic Editor$'  # "PROJECT [HIERARCHY_PATH] - Schematic Editor"
-            self.pn_window_title = r'PCB Editor$'
+            self.pn_window_title = r'.* — PCB Editor$'  # "PROJECT - PCB Editor"
         else:
             # KiCad 5.1.6
             self.ee_window_title = r'Eeschema.*\.sch'  # "Eeschema - file.sch"
@@ -291,4 +291,4 @@ __license__ = 'Apache 2.0'
 __email__ = 'stropea@inti.gob.ar'
 __status__ = 'stable'
 __url__ = 'https://github.com/INTI-CMNB/KiAuto/'
-__version__ = '1.6.11'
+__version__ = '1.6.13'
